<?php
/**
 * Theme functions and definitions
 *
 * Set up the theme and provide some helper functions.
 *
 * Note: Do NOT add any custom code here. Please use a child theme so that your customizations aren't lost during updates.
 */

if ( ! function_exists( 'katerina_theme_setup' ) ) :

	/**
	 * Theme setup function.
	 */
	function katerina_theme_setup() {

		/*
		 * Make theme available for translation.
		 * Translations can be placed in the /languages/ directory.
		 */
		load_theme_textdomain( 'katerina', get_template_directory() . '/languages' );

		// This theme uses wp_nav_menu() in the header and footer sections.
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Menu', 'katerina' ),
				'social'  => esc_html__( 'Social Links Menu', 'katerina' ),
			)
		);

		/*
		 * Sets the content width in pixels, based on the theme's design and stylesheet.
		 */
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 640;
		}

		/*
		 * Enable support for posts and comments RSS feed links.
		 */
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for custom logo.
		 */
		add_theme_support(
			'custom-logo',
			array(
				'width'       => 120,
				'height'      => 40,
				'flex-height' => true,
				'flex-width'  => true,
			)
		);

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 */
		add_theme_support( 'post-thumbnails' );

		/*
		 * Enable admin bar personal CSS position style.
		 */
		add_theme_support(
			'admin-bar',
			array(
				'callback' => '__return_false',
			)
		);

		/*
		 * Switch default core markup for search form, comment form, and comments to output valid HTML5.
		 */
		add_theme_support(
			'html5',
			array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			)
		);

		/*
		 * Enable support for Post Formats.
		 */
		add_theme_support(
			'post-formats',
			array(
				'chat',
				'gallery',
				'link',
				'image',
				'quote',
				'status',
				'video',
				'audio',
			)
		);

		/*
		 * Enable support for selective refresh in the Customizer.
		 */
		add_theme_support( 'customize-selective-refresh-widgets' );

		/*
		 * Enable support for the block editor wide elements and responsive embeds.
		 */
		add_theme_support( 'editor-styles' );
		add_theme_support( 'align-wide' );
		add_theme_support( 'responsive-embeds' );

		/*
		 * Style only the classic editor to somehow resemble the
		 frontend theme style, specifically font, colors, etc.
		 */
		if ( ! katerina_has_block_editor() ) {
			add_editor_style( array( 'assets/css/editor.css' ) );
		}
	}

endif; // katerina_theme_setup.

add_action( 'after_setup_theme', 'katerina_theme_setup' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function katerina_pingback_header() {
	if ( is_singular() && pings_open() && get_bloginfo( 'pingback_url' ) ) {
		printf( '<link rel="pingback" href="%s">' . "\n", esc_url( get_bloginfo( 'pingback_url' ) ) );
	}
}
add_action( 'wp_head', 'katerina_pingback_header' );

/**
 * Registers the default widget area.
 */
function katerina_widgets_init() {

	register_sidebar(
		array(
			'name'          => esc_html__( 'Page Sidebar', 'katerina' ),
			'id'            => 'page-sidebar',
			'description'   => esc_html__( 'Add widgets here to appear in your sidebar on pages like blogs, archives or episode listings.', 'katerina' ),
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

	register_sidebar(
		array(
			'name'          => esc_html__( 'Footer', 'katerina' ),
			'id'            => 'footer',
			'description'   => esc_html__( 'Add widgets here to appear in your footer.', 'katerina' ),
			'before_widget' => '<div id="%1$s" class="widget %2$s">',
			'after_widget'  => '</div>',
			'before_title'  => '<h4 class="widget-title">',
			'after_title'   => '</h4>',
		)
	);

}
add_action( 'widgets_init', 'katerina_widgets_init' );

/**
 * Enqueues scripts and styles.
 */
function katerina_scripts_styles() {
	global $wp_query;
	if ( $wp_query->is_singular ) {
		$katerina_current_post_id = $wp_query->queried_object_id;
	} elseif ( is_home() && ! is_front_page() ) {
		$katerina_current_post_id = get_option( 'page_for_posts' );
	} elseif ( class_exists( 'WooCommerce' ) && is_shop() ) {
		$katerina_current_post_id = get_option( 'woocommerce_shop_page_id' );
	}
	$katerina_theme_version = wp_get_theme()->get( 'Version' );

	// Theme main CSS
	wp_enqueue_style( 'katerina', get_stylesheet_uri(), array(), $katerina_theme_version );

	// Footer gallery module
	if ( 0 !== get_theme_mod( 'footer_gallery_active', 0 ) ) {
		wp_enqueue_style( 'katerina-footer-gallery', get_template_directory_uri() . '/assets/css/footer-gallery.css', array( 'katerina' ), $katerina_theme_version );
	}

	$katerina_dependencies = array( 'jquery' );
	if ( isset( $katerina_current_post_id ) ) {
		$featured_area_type = get_post_meta( $katerina_current_post_id, 'featured_area_type', true );

		// Style the featured hero module
		if ( ! empty( $featured_area_type ) ) {
			wp_enqueue_style( 'katerina-featured-hero', get_template_directory_uri() . '/assets/css/featured-hero.css', array( 'katerina' ), $katerina_theme_version );
		}

		$custom_slider = get_post_meta( $katerina_current_post_id, 'custom_featured_area', true );
		if ( 'slider' === $featured_area_type && ! empty( $custom_slider ) ) {
			$katerina_dependencies[] = 'threejs';
			wp_enqueue_script( 'threejs', get_template_directory_uri() . '/assets/js/three.min.js', array(), $katerina_theme_version, true );
			$katerina_dependencies[] = 'katerina-displacement-slider';
			wp_enqueue_script( 'katerina-displacement-slider', get_template_directory_uri() . '/assets/js/displacement-slider.js', array( 'threejs' ), $katerina_theme_version, true );
		}
	} else {
		if ( is_404() ) {
			wp_enqueue_style( 'katerina-featured-hero', get_template_directory_uri() . '/assets/css/featured-hero.css', array( 'katerina' ), $katerina_theme_version );
		}
	}

	// Theme main JS
	wp_enqueue_script( 'katerina', get_template_directory_uri() . '/assets/js/functions.js', $katerina_dependencies, $katerina_theme_version, true );

	if ( ! is_admin() && is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'katerina_scripts_styles' );

/**
 * Enqueues custom Modernizr
 */
function katerina_script_features() {
	$katerina_theme_version  = wp_get_theme()->get( 'Version' );

	// Custom Modernizr
	wp_enqueue_script( 'katerina-features', get_template_directory_uri() . '/assets/js/detect-support.js', array(), $katerina_theme_version, false );
}
add_action( 'wp_enqueue_scripts', 'katerina_script_features', 0 );

// Add standard theme functionality (filters, hooks).
require get_parent_theme_file_path( '/inc/setup.php' );

// Add theme options for the WordPress Customizer.
require get_parent_theme_file_path( '/inc/customizer/customizer.php' );

// Add theme custom CSS (depending on the Customizer options).
require get_parent_theme_file_path( '/inc/custom-css.php' );

// SVG icons functions and filters.
require get_parent_theme_file_path( '/inc/svg-icons.php' );

// Add WooCommerce integration.
if ( class_exists( 'WooCommerce' ) && file_exists( get_parent_theme_file_path( 'inc/woocommerce-config.php' ) ) ) {
	require get_parent_theme_file_path( '/inc/woocommerce-config.php' );
}
