<?php
/**
 * SVG icons related functions and filters.
 */

/**
 * Add SVG definitions to the footer.
 */
function katerina_include_svg_icons() {
	$svg_icons = get_parent_theme_file_path( '/assets/images/svg-icons.svg' );
	if ( file_exists( $svg_icons ) ) {
		require $svg_icons;
	}
}
add_action( 'wp_footer', 'katerina_include_svg_icons', 9999 );

/**
 * Return SVG markup.
 */
function katerina_get_svg( $args = array() ) {
	// Set defaults.
	$defaults = array(
		'icon'     => '',
		'title'    => '',
		'desc'     => '',
		'fallback' => false,
	);

	if ( ! is_array( $args ) ) {
		$args = array(
			'icon' => $args,
		);
	}

	// Parse args.
	$args = wp_parse_args( $args, $defaults );

	// Set aria hidden.
	$aria_hidden = ' aria-hidden="true"';

	// Set ARIA.
	$aria_labelledby = '';

	if ( $args['title'] ) {
		$aria_hidden     = '';
		$unique_id       = uniqid();
		$aria_labelledby = ' aria-labelledby="title-' . $unique_id . '"';

		if ( $args['desc'] ) {
			$aria_labelledby = ' aria-labelledby="title-' . $unique_id . ' desc-' . $unique_id . '"';
		}
	}

	// Begin SVG markup.
	$svg = '<svg class="icon icon-' . esc_attr( $args['icon'] ) . '"' . $aria_hidden . $aria_labelledby . ' role="img">';

	// Display the title.
	if ( $args['title'] ) {
		$svg .= '<title id="title-' . $unique_id . '">' . esc_html( $args['title'] ) . '</title>';
		if ( $args['desc'] ) {
			$svg .= '<desc id="desc-' . $unique_id . '">' . esc_html( $args['desc'] ) . '</desc>';
		}
	}

	$svg .= '<use href="#icon-' . esc_html( $args['icon'] ) . '" xlink:href="#icon-' . esc_html( $args['icon'] ) . '"></use>';

	// Add some markup to use as a fallback for browsers that do not support SVGs.
	if ( $args['fallback'] ) {
		$svg .= '<span class="svg-fallback icon-' . esc_attr( $args['icon'] ) . '"></span>';
	}

	$svg .= '</svg>';

	return $svg;
}

if ( ! function_exists( 'katerina_theme_svg' ) ) {
	/**
	 * Output and get theme SVG icon, already escaped in katerina_get_svg().
	 */
	function katerina_theme_svg( $args = array() ) {
		echo katerina_get_svg( $args ); //phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped -- Escaped in katerina_get_svg();.
	}
}

/**
 * Display SVG icons in social links menu.
 *
 * @param  string  $item_output The menu item output.
 * @param  WP_Post $item        Menu item object.
 * @param  int     $depth       Depth of the menu.
 * @param  array   $args        wp_nav_menu() arguments.
 * @return string  $item_output The menu item output with social icon.
 */
function katerina_nav_menu_social_icons( $item_output, $item, $depth, $args ) {
	// Get supported social icons.
	$social_icons = katerina_social_links_icons();
	$found        = false;

	// Change SVG icon inside social links menu if there is supported URL.
	if ( false !== strpos( $args->menu->slug, 'social' ) || 'social' === $args->theme_location ) {
		foreach ( $social_icons as $attr => $value ) {
			if ( false != strpos( $item_output, $attr ) ) {
				$found       = true;
				$item_output = str_replace( '">', '">' . katerina_get_svg( array( 'icon' => esc_attr( $value ) ) ) . '<span class="screen-reader-text">', $item_output );
				$item_output = str_replace( '</a>', '</span></a>', $item_output );
				continue;
			}
		}
		if ( ! $found ) {
			$item_output = str_replace( '">', '">' . katerina_get_svg( array( 'icon' => 'link-exterior' ) ) . '<span class="screen-reader-text">', $item_output );
			$item_output = str_replace( '</a>', '</span></a>', $item_output );
		}
	}

	return $item_output;
}
add_filter( 'walker_nav_menu_start_el', 'katerina_nav_menu_social_icons', 10, 4 );

/**
 * Returns an array of supported social links (URL and icon name).
 *
 * @return array $social_links_icons
 */
function katerina_social_links_icons() {
	// Supported social links icons.
	$social_links_icons = array(
		'airbnb.com'      => 'airbnb',
		'amazon.com'      => 'amazon',
		'amazon.cn'       => 'amazon',
		'amazon.in'       => 'amazon',
		'amazon.fr'       => 'amazon',
		'amazon.de'       => 'amazon',
		'amazon.it'       => 'amazon',
		'amazon.nl'       => 'amazon',
		'amazon.es'       => 'amazon',
		'amazon.co'       => 'amazon',
		'amazon.ca'       => 'amazon',
		'apple.com'       => 'apple',
		'behance.net'     => 'behance',
		'booking.com'     => 'booking',
		'codepen.io'      => 'codepen',
		'deviantart.com'  => 'deviantart',
		'docker.com'      => 'docker',
		'dribbble.com'    => 'dribbble',
		'dropbox.com'     => 'dropbox',
		'facebook.com'    => 'facebook',
		'flickr.com'      => 'flickr',
		'foursquare.com'  => 'foursquare',
		'github.com'      => 'github',
		'instagram.com'   => 'instagram',
		'itunes.com'      => 'apple',
		'last.fm'         => 'lastfm',
		'linkedin.com'    => 'linkedin',
		'mailto:'         => 'email',
		'medium.com'      => 'medium',
		'pinterest.com'   => 'pinterest',
		'reddit.com'      => 'reddit',
		'skype.com'       => 'skype',
		'skype:'          => 'skype',
		'snapchat.com'    => 'snapchat',
		'soundcloud.com'  => 'soundcloud',
		'spotify.com'     => 'spotify',
		'tripadvisor.com' => 'tripadvisor',
		'tumblr.com'      => 'tumblr',
		'twitch.tv'       => 'twitch',
		'twitter.com'     => 'twitter',
		'vimeo.com'       => 'vimeo',
		'vk.com'          => 'vk',
		'wordpress.org'   => 'wordpress',
		'wordpress.com'   => 'wordpress',
		'yelp.com'        => 'yelp',
		'youtube.com'     => 'youtube',
		'/feed/'          => 'rss',
	);

	// Filter social links icons.
	return apply_filters( 'katerina_social_links_icons', $social_links_icons );
}
